@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::AlienBase::Doc 0.32 {
+package Dist::Zilla::Plugin::AlienBase::Doc 0.33 {
 
   use 5.014;
   use Moose;
@@ -206,7 +206,7 @@ Dist::Zilla::Plugin::AlienBase::Doc - Generate boilerplate documentation for Ali
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 SYNOPSIS
 
@@ -287,11 +287,15 @@ List of modules to refer to in the C<SEE ALSO> section.  By default this is
 
 =head1 AUTHOR
 
-Graham Ollis <plicease@cpan.org>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+Contributors:
+
+Curtis Jewell (CSJEWELL)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Graham Ollis.
+This software is copyright (c) 2017-2025 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
